# CHANGELOG


## v0.1.2 (2025-07-11)

### Bug Fixes

- Fix rcc location within build
  ([`31e288f`](https://github.com/bec-project/qtmonaco/commit/31e288f4d2b2c4d7f5872616183a2db5d07a68c2))


## v0.1.1 (2025-07-11)

### Bug Fixes

- Fix release step
  ([`182c7de`](https://github.com/bec-project/qtmonaco/commit/182c7dec74c46437e1a56d03c53b9992b135ad90))


## v0.1.0 (2025-07-11)

### Continuous Integration

- Add pypi build and upload
  ([`25ea54a`](https://github.com/bec-project/qtmonaco/commit/25ea54a80e6fd54a215cb3679ca80e8e49c8e97b))

- Init
  ([`0b5ef18`](https://github.com/bec-project/qtmonaco/commit/0b5ef1858bc95ec93e6c8abb993b1e01f8772cac))

### Features

- Add qt bridge
  ([`7361271`](https://github.com/bec-project/qtmonaco/commit/73612710b57424234900863606fe3aa74ad6754f))
